summaryrefslogtreecommitdiffstats
path: root/src/k3bapplication.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/k3bapplication.cpp')
-rw-r--r--src/k3bapplication.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/k3bapplication.cpp b/src/k3bapplication.cpp
index 73fd5fb..b9640bc 100644
--- a/src/k3bapplication.cpp
+++ b/src/k3bapplication.cpp
@@ -315,8 +315,8 @@ void K3bApplication::slotShutDown()
-K3bApplication::Core::Core( TQObject* tqparent )
- : K3bCore( tqparent ),
+K3bApplication::Core::Core( TQObject* parent )
+ : K3bCore( parent ),
m_appDeviceManager(0),
m_mediaCache(0)
{
@@ -424,7 +424,7 @@ bool K3bApplication::Core::internalBlockDevice( K3bDevice::Device* dev )
//
// Check if the device is in use
//
// FIXME: Use the top level widget as tqparent
K3bLsofWrapperDialog::checkDevice( dev );
return true;
@@ -424,7 +424,7 @@ bool K3bApplication::Core::internalBlockDevice( K3bDevice::Device* dev )
// Check if the device is in use
//
- // FIXME: Use the top level widget as tqparent
+ // FIXME: Use the top level widget as parent
K3bLsofWrapperDialog::checkDevice( dev );
return true;